export declare class TimeoutError extends Error {
    constructor(message?: string);
}
/**
An error to be thrown when the request is aborted by AbortController.
DOMException is thrown instead of this Error when DOMException is available.
 */
export declare class AbortError extends Error {
    constructor(message?: string);
}
type Options<R> = {
    /**
    Timeout in milliseconds.
     */
    milliseconds: number;
    /**
    Fallback value to return when the promise times out.
     */
    fallback?: () => R;
    /**
    Custom error message to use when the promise times out.
     */
    message?: string | Error | false;
    /**
    Signal to abort the promise.
     */
    signal?: AbortSignal;
    /**
    Custom timers to use.
     */
    customTimers?: {
        setTimeout: typeof setTimeout;
        clearTimeout: typeof clearTimeout;
    };
};
export default function pTimeout<R>(promise: Promise<R | undefined>, options: Options<R>): Promise<any>;
export {};
